@@ -4,7 +4,7 @@ use base 'Log::Dispatch::Output';
 # Make sure we have version info for this module
 # Be strict from now on
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 use strict;
 
 # Satisfy require
@@ -99,7 +99,7 @@ Log::Dispatch::Buffer - Base class for collecting logged messages
 
 =head1 VERSION
 
-This documentation describes version 0.02.
+This documentation describes version 0.03.
 
 =head1 DESCRIPTION
 
@@ -146,7 +146,9 @@ in L<Log::Dispatch/"CONVENIENCE METHODS">)..
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
 
-Please report bugs to <perlbugs@dijkmat.nl>.
+Maintained by Robert Acock
+
+Please report bugs to <email@lnation.org>.
 
 =head1 COPYRIGHT
 
